Change log for dtool-lookup-gui
===============================

0.4.3 (17Feb22)
--------------

- README.yml template file chooser in settings dialog
- User name and eMail configurable in settings dialog

0.4.2 (09Feb22)
---------------

- Config reset/import/export buttons in settings dialog

0.4.1 (04Feb22)
---------------

- Usable and stable on Windows 10 and Ubuntu 20.04
- Published as PyInstaller-bundled one-file exectuable on GitHub releases
- Download of single items by double-click on manifest entry

0.4.0 (16Dec21)
---------------

- Manage (create, edit, freeze, copy) datasets in local directories and on
  remote (cloud) storage systems
- Configure dtool cloud endpoints

0.3.0 (15May21)
---------------

- Download files from manifest

0.2.1 (26Oct20)
---------------

- Show missing datasets with triangles
- Bug: Missing datasets
- Bug: Symbols in graph view

0.2.0 (26Oct20)
---------------

- Warn about missing UUIDs
- Tree view for manifest (#2)

0.1.2 (24Oct20)
---------------

- Removed debug print

0.1.1 (24Oct20)
---------------

- Show server version in status bar

0.1.0 (8Oct20)
--------------

- GTK client for dtool-lookup-server
- List all datasets and full text search
- Show metadata (README.yml) and manifest
- Optional: MongoDB queries
- Optional: Depedency graph visualization 
